#
# spec file for package ipcalc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ipcalc
Version:        1.0.3
Release:        2.2
Summary:        IPv4/IPv6 tool assisting in network calculations on the command line
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://gitlab.com/ipcalc/ipcalc
Source0:        https://gitlab.com/ipcalc/ipcalc/-/archive/%{version}/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE ipcalc-disable-network-tests.patch badshah400@gmail.com -- Disable tests requiring network
Patch0:         ipcalc-disable-network-tests.patch
BuildRequires:  /usr/bin/ronn
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libmaxminddb)
Conflicts:      netcalc

%description
ipcalc is a modern tool to assist in network address calculations for IPv4 and
IPv6. It acts both as a tool to output human readable information about a
network or address, as well as a tool suitable to be used by scripts or other
programs.  It supports printing a summary about the provided network address,
multiple command line options per information to be printed, transparent IPv6
support, and in addition it will use libGeoIP if available to provide
geographic information.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%files
%doc README.md NEWS
%license COPYING
%{_bindir}/ipcalc
%{_mandir}/man1/ipcalc.1%{?ext_man}

%changelog
* Fri Aug 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire /usr/bin/ronn instead of rubygem(ronn): there are
  alternatives around and the build does not care wich one is used.
* Tue Jun 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.3:
  * When --no-decorate is given the default output will
  * include no colors
  * Correctly split networks with /31
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Fix ULA prefix generator to use only defined ULA range
  * Corrected manpage generation
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  - The application will now build even without ronn
  - Improved JSON output on single host input
* Sat Apr  3 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.0:
  * Manpage was converted to markdown.
- Switch to using meson for building; BuildRequires: meson >=
  0.49.
- Addtional BuildRequires now needed: pkgconfig(libmaxminddb),
  rubygem(ronn).
- Add ipcalc-disable-network-tests.patch: Disable tests requiring
  network.
- Run tests as part of %%check section.
- New upstream URL and Source URL.
- Drop patch patch-queue: no longer needed.
* Tue Aug  4 2015 mpluskal@suse.com
- Cleanup spec file with spec-clenaer
* Sun Jun 26 2011 lazy.kent@opensuse.org
- refreshed patch to fix build in openSUSE >= 11.3
- splitted off rpm changelog to changes
- corrected License tag
- added Authors
- formatted spec
* Sun Nov 18 2007 guru@unixtech.be
- moved to openSUSE Build Service
- added minor patch
* Sun Oct 22 2006 guru@unixtech.be
- new upstream version
- rewrote spec file
